@@ -15,8 +15,9 @@
 #include "comp_mzlib2.h"
 #endif
 #include "comp_factor.h"
-#include "comp_range.h"
 #endif
+#include "comp_range.h"
+#include "comp_snibble.h"
 #include "comp_text.h"
 #include "comp_fail.h"
 
@@ -31,9 +32,15 @@ int (*(algorithms[256]))()={    comp_plain_algo,
 				comp_fail_algo,
 				comp_fail_algo,
 #endif
+				comp_snibble_algo,
+				comp_range_algo,
 #ifdef DEBUG
 				comp_factor_algo,
-				comp_range_algo,
+#ifdef USE_ZLIB
+/*	comp_mzlib2_algo, */	comp_fail_algo,
+#else
+				comp_fail_algo,
+#endif
 #else
 				comp_fail_algo,
 				comp_fail_algo,
@@ -51,12 +58,18 @@ char *algorithm_names[256]={	"Uncompressed",
 				"Unsupported Algorithm (zlib)",
 				"Unsupported Algorithm (mzlib)",
 #endif
+				"Seminibble Encoding",
+				"Range Encoding",
 #ifdef DEBUG
 				"Factor Compression",
-				"Range Encoding",
+#ifdef USE_ZLIB
+				"Second Modified Zlib",
+#else
+				"Unsupported Algorithm (mzlib2)",
+#endif
 #else
 				"Unsupported Algorithm (factor)",
-				"Unsupported Algorithm (range)",
+				"Unsupported Algorithm (mzlib2)",
 #endif
 				NULL
 			};
