@@ -1,6 +1,7 @@
 #ifndef port_h
 #define port_h
 #include <limits.h>
+#include <sys/types.h>
 
 #ifdef GCC
 #define Inline inline
@@ -16,6 +17,8 @@ typedef unsigned int   uint2;
 typedef unsigned long  uint4;
 #endif
 
+#ifdef NEED_UINT
 typedef unsigned int uint;     /* fast unsigned integer, 2 or 4 bytes  */
+#endif
 
 #endif
