@@ -1,7 +1,26 @@
+/*
+ * Copyright (C) 2000  Roy Keene
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *
+ *      email: rkeene@netfueldesign.com
+ */
+
+
 /*
 	Dynamic Compression Routines 
-		- OR -
-	Compression dictionary.
 */
 
 #include <sys/types.h>
@@ -185,7 +204,7 @@ int main(int argc, char **argv) {
 					return(-1);
 				}
 				if (option_verbose>1) {
-					printf("Block #%05i: algo=%03i (size=%05i, %05i)  %35s\n", x,out_algo,out_lowest,out_lowest+sizeof(header.algo)+sizeof(header.size),algorithm_names[out_algo]);
+					printf("Block #%05i: algo=%03i (size=%05i, %05i)  %35s\n", x,out_algo,out_lowest,(int) (out_lowest+sizeof(header.algo)+sizeof(header.size)),algorithm_names[out_algo]);
 				}
 				if (option_verbose==1) {
 					printf("Block %5i/%5i\r",x,(int) (((float) (((float) file_size)/DACT_BLK_SIZE))+0.99));
