@@ -1,6 +1,8 @@
+#ifndef _DACT_H
+#define _DACT_H
 #define DACT_VER_MAJOR 0
 #define DACT_VER_MINOR 3
-#define DACT_VER_REVISION 17
+#define DACT_VER_REVISION 21
 
 #ifndef DACT_BLK_SIZE
 #define DACT_BLK_SIZE 1024
@@ -10,14 +12,25 @@
 #define DACT_MODE_COMPR 1
 #define DACT_MODE_DECMP 2
 
-#ifndef TWO_BYTES
+
 #if defined(__WIN32__) || defined(GO32)
-#undef USE_ZLIB
+#ifndef TWO_BYTES
 #define TWO_BYTES unsigned int
+#endif
+#ifndef FOUR_BYTES
+#define FOUR_BYTES unsigned long
+#endif
+#undef USE_ZLIB
 #else
+#ifndef TWO_BYTES
 #define TWO_BYTES unsigned short
-#endif defined(__WIN32__) || defined(GO32)
-#endif !defined(TWO_BYTES)
+#endif
+#ifndef FOUR_BYTES
+#define FOUR_BYTES unsigned int
+#endif
+#endif
+
+
 
 struct dact_header {
 /*
@@ -27,3 +40,4 @@ struct dact_header {
 	TWO_BYTES	size;
 	unsigned char	algo;
 };
+#endif
